@@ -2,6 +2,7 @@
 from .app import Starlite
 from .config import CORSConfig, OpenAPIConfig
 from .controller import Controller
+from .dto import DTOFactory
 from .enums import (
     HttpMethod,
     MediaType,
@@ -13,6 +14,7 @@ from .exceptions import (
     HTTPException,
     ImproperlyConfiguredException,
     InternalServerException,
+    MissingDependencyException,
     NotAuthorizedException,
     NotFoundException,
     PermissionDeniedException,
@@ -35,6 +37,7 @@ from .logging import LoggingConfig
 from .middleware import AbstractAuthenticationMiddleware, AuthenticationResult
 from .openapi.controller import OpenAPIController
 from .params import Body, Parameter
+from .plugins import PluginProtocol, SQLAlchemyPlugin
 from .provide import Provide
 from .request import Request, WebSocket
 from .response import Response
@@ -50,6 +53,7 @@ __all__ = [
     "Body",
     "CORSConfig",
     "Controller",
+    "DTOFactory",
     "File",
     "HTTPException",
     "HTTPRoute",
@@ -60,6 +64,7 @@ __all__ = [
     "LoggingConfig",
     "MediaType",
     "MiddlewareProtocol",
+    "MissingDependencyException",
     "NotAuthorizedException",
     "NotFoundException",
     "OpenAPIConfig",
@@ -68,6 +73,7 @@ __all__ = [
     "Parameter",
     "Partial",
     "PermissionDeniedException",
+    "PluginProtocol",
     "Provide",
     "Redirect",
     "Request",
@@ -75,6 +81,7 @@ __all__ = [
     "Response",
     "ResponseHeader",
     "Router",
+    "SQLAlchemyPlugin",
     "ScopeType",
     "ServiceUnavailableException",
     "StarLiteException",
