@@ -1,8 +1,13 @@
 from enum import Enum
-from typing import Any, cast
+from typing import TYPE_CHECKING, Any, cast
 
 from starlite.exceptions import ImproperlyConfiguredException
 
+if TYPE_CHECKING:  # pragma: no cover
+    from starlite.types import Method
+else:
+    Method = Any
+
 
 class HttpMethod(str, Enum):
     GET = "get"
@@ -19,10 +24,15 @@ class HttpMethod(str, Enum):
     @classmethod
     def from_str(cls, value: Any) -> "HttpMethod":
         """Given a string value, return an enum member or raise a ValueError"""
+
         if cls.is_http_method(value):
             return cast(HttpMethod, value.lower())
         raise ImproperlyConfiguredException(f"value {value} is not a supported http method")
 
+    def to_str(self) -> "Method":
+        """Returns the string value as an upper cased string: get -> GET"""
+        return cast(Method, self.value.upper())
+
 
 class MediaType(str, Enum):
     JSON = "application/json"
@@ -39,3 +49,8 @@ class RequestEncodingType(str, Enum):
     JSON = "application/json"
     MULTI_PART = "multipart/form-data"
     URL_ENCODED = "application/x-www-form-urlencoded"
+
+
+class ScopeType(str, Enum):
+    HTTP = "http"
+    WEBSOCKET = "websocket"
