@@ -1,18 +1,16 @@
 # flake8: noqa
-from .model import (
-    convert_dataclass_to_model,
-    create_function_signature_model,
-    create_parsed_model_field,
-)
+from .model import convert_dataclass_to_model, create_parsed_model_field
 from .sequence import find_index, unique
+from .signature import SignatureModel, create_function_signature_model
 from .url import join_paths, normalize_path
 
 __all__ = [
+    "SignatureModel",
+    "convert_dataclass_to_model",
+    "create_function_signature_model",
+    "create_parsed_model_field",
+    "find_index",
     "join_paths",
     "normalize_path",
-    "find_index",
     "unique",
-    "create_parsed_model_field",
-    "create_function_signature_model",
-    "convert_dataclass_to_model",
 ]
